⑩

### Dark Mode / Theme-Aware

Polish
Dark
Dark Mode
Task Completion
65% of sprint complete
Light Mode
Task Completion
65% of sprint complete
Live Preview (toggle above)
32
Active Tasks
72
Health Score
5.3d
Avg Cycle
⑪

### Clickable Everything

Polish

Task | Status | Assignee | Events
--- | --- | --- | ---
LAT-47 | in_progress Click to filter by in_progress | C agent:claude-opus-4 | 12
LAT-45 | review Click to filter by review | A human:atin | 8
LAT-42 | in_progress Click to filter by in_progress | X agent:codex | 15

⑫

### Time Range Selector

Polish
7d
30d
90d
All
📈 Chart data would update to show: last 30 days
⑬

### Collapsible Sections

Polish
▸ Status Distribution 5 in_progress, 3 review, 12 done...
in_progress
5
review
3
planned
4
done
12
backlog
8
▸ Priority Breakdown 2 urgent, 7 high, 15 normal, 8 low
Urgent
2
High
7
Normal
15
Low
8
▸ Tag Distribution core: 11, cli: 8, dashboard: 5, storage: 4
core
11
cli
8
dashboard
5
storage
4
⑳

### Export / Share

Feature
✍
Copy as Markdown
Clipboard-ready
{}
Export JSON
Machine-readable
📄
Generate Report
Formatted summary
Preview Markdown

    ## Lattice Stats — Feb 15, 2026
    - Active tasks: 32 (↑3 from last week)
    - Completed this week: 3
    - Health: Partly Cloudy (72/100)
    - Bottleneck: review (avg 12.7d)
    - Attention: LAT-18 stale 12d, blocking 2 tasks

㉖

### Top 5 Recommended Actions

Feature
Unblock LAT-18 — "Add relationship validation"
Stale 12d in in_progress, blocking LAT-31 and LAT-33 (chain depth 2)
→ Review and resolve or reassign
Reduce WIP — in_progress at 5/4 limit
Consider moving LAT-38 "Add tag filtering" to review
→ Move oldest in_progress task forward
Assign LAT-22 — "Design artifact linking UX"
Planned but unassigned for 14 days, stale
→ Assign to available agent or deprioritize
Review LAT-45 — "Fix event replay ordering"
In review for 5h, all tests passing
→ Merge if approved
Plan next sprint — 4 tasks in backlog
LAT-35 (high priority) and LAT-34 ready for planning
→ Move highest-priority backlog items to planned